/* Global for all skins */
/*
.body_style_fullscreen:not(.elementor-editor-active) {
	&:not(.sc_stack_section_present),
	&:not(.fixed_blocks_sticky) {
		.content_wrap_fullscreen {
			overflow: hidden;	// Used to prevent the horizontal scroll bar.
								// But this rule broke a sticky effect for sections - they are jumping down when any rows become fixed
								// and a scroll animation with flow=sticky doesn't work
		}
	}
}
.body_style_fullscreen:not(.elementor-editor-active) {
	&.sc_stack_section_present,
	&.fixed_blocks_sticky {
		.content_wrap_fullscreen {
			overflow: clip; 	// This rule is used to prevent the horizontal scroll bar
								// and a sticky effect for sections works fine.
								// Need to check it on other devices and browsers!
		}
	}
}
*/
body.body_style_fullscreen .content_wrap_fullscreen {
  overflow: clip !important;
}

/* QW Extension icons */
[class^="qw_extension_icon-"]:before,
[class*=" qw_extension_icon-"]:before {
  font-size: inherit;
  line-height: inherit !important;
  font-weight: inherit;
  font-style: inherit;
  display: inline-block;
  width: auto;
  margin: 0;
}

/* Large Dot */
.trx_addons_mouse_helper_style_dot:not(.trx_addons_mouse_helper_with_layout) {
  --mouse-helper-width: 14px;
  --mouse-helper-height: 14px;
}
.trx_addons_mouse_helper_style_dot:not(.trx_addons_mouse_helper_with_layout).trx_addons_mouse_helper_active {
  --mouse-helper-width: 30px;
  --mouse-helper-height: 30px;
}

/* Controls -> Simple */
.sc_slider_controls.sc_slider_controls_simple.slider_pagination_style_title.sc_align_right .slider_pagination_wrap {
  text-align: right;
}
.sc_slider_controls.sc_slider_controls_simple.slider_pagination_style_title.sc_align_left .slider_pagination_wrap {
  text-align: left;
}
.sc_slider_controls.sc_slider_controls_simple.slider_pagination_style_title .slider_pagination_wrap {
  counter-reset: item;
  list-style-type: none;
}
.sc_slider_controls.sc_slider_controls_simple.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet {
  font-size: 1.33em;
  line-height: 1.2em;
  font-weight: var(--theme-font-h5_font-weight);
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  opacity: 0.5 !important;
  margin: 0 !important;
  color: var(--theme-color-text_dark);
}
.sc_slider_controls.sc_slider_controls_simple.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet + .slider_pagination_bullet {
  margin-top: 25px !important;
}
.sc_slider_controls.sc_slider_controls_simple.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet:before {
  display: inline-block;
  margin-right: 10px;
  color: var(--theme-color-text_light);
  content: counter(item,decimal-leading-zero) ". ";
  counter-increment: item;
}
.sc_slider_controls.sc_slider_controls_simple.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet:hover, .sc_slider_controls.sc_slider_controls_simple.slider_pagination_style_title .slider_pagination_wrap .slider_pagination_bullet.slider_pagination_bullet_active {
  opacity: 1 !important;
}
.sc_slider_controls.sc_slider_controls_simple .slider_prev + .slider_next,
.sc_slider_controls.sc_slider_controls_simple .slider_prev + .slider_pagination_wrap,
.sc_slider_controls.sc_slider_controls_simple .slider_next + .slider_pagination_wrap {
  margin-left: 0.8em;
}
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_next,
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_prev {
  border: none;
  width: 50px;
  height: 50px;
  line-height: 50px;
  text-align: center;
  padding: 0;
  background-color: transparent;
  color: var(--theme-color-text_dark);
}
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_next:before,
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_prev:before {
  display: block;
  font-family: "qw_extension_icons";
  font-size: 24px;
  content: '\e803';
}
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_next.with_title,
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_prev.with_title {
  padding: 0;
  width: auto;
}
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_next.with_title:before,
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_prev.with_title:before {
  display: none;
}
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_next:hover,
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_prev:hover {
  color: var(--theme-color-text_link);
}
.sc_slider_controls.sc_slider_controls_simple .slider_controls_wrap > a.slider_prev:before {
  -webkit-transform: scale(-1, 1);
  -ms-transform: scale(-1, 1);
  transform: scale(-1, 1);
}

/*# sourceMappingURL=qw-extension.css.map */
